Merge branch 'rocm-rel-1.3' into amd-develop
Conflicts: include/hip/nvcc_detail/hip_runtime_api.h Change-Id: I990a7d008da9e8dcc68250cebbc8ee6e723c7e01
This commit is contained in:
+1
-1
@@ -164,7 +164,7 @@ if(HIP_PLATFORM STREQUAL "hcc")
|
||||
set(HIP_HCC_BUILD_FLAGS "${HIP_HCC_BUILD_FLAGS} -DHIP_VERSION_MAJOR=${HIP_VERSION_MAJOR} -DHIP_VERSION_MINOR=${HIP_VERSION_MINOR} -DHIP_VERSION_PATCH=${HIP_VERSION_PATCH}")
|
||||
|
||||
# Add remaining flags
|
||||
set(HIP_HCC_BUILD_FLAGS "${HIP_HCC_BUILD_FLAGS} -fPIC -hc -I${HCC_HOME}/include -I${HSA_PATH}/include -I/opt/rocm/libhsakmt/include -stdlib=libc++")
|
||||
set(HIP_HCC_BUILD_FLAGS "${HIP_HCC_BUILD_FLAGS} -fPIC -hc -I${HCC_HOME}/include -I${HSA_PATH}/include -I/opt/rocm/libhsakmt/include -I/usr/local/include/c++/v1 -stdlib=libc++")
|
||||
|
||||
# Set compiler and compiler flags
|
||||
set(CMAKE_CXX_COMPILER "${HCC_HOME}/bin/hcc")
|
||||
|
||||
+17
@@ -13,8 +13,25 @@ Upcoming:
|
||||
|
||||
## Revision History:
|
||||
|
||||
===================================================================================================
|
||||
Release:1.0
|
||||
Date: 2016.11.8
|
||||
- Initial implementation for FindHIP.cmake
|
||||
- HIP library now installs as a static library by default
|
||||
- Added support for HIP context and HIP module APIs
|
||||
- Major changes to HIP signal & memory management implementation
|
||||
- Support for complex data type and math functions
|
||||
- clang-hipify is now known as hipify-clang
|
||||
- Added several new HIP samples
|
||||
- Preliminary support for new APIs: hipMemcpyToSymbol, hipDeviceGetLimit, hipRuntimeGetVersion
|
||||
- Added support for async memcpy driver API (for example hipMemcpyHtoDAsync)
|
||||
- Support for memory management device functions: malloc, free, memcpy & memset
|
||||
- Removed deprecated HIP runtime header locations. Please include "hip/hip_runtime.h" instead of "hip_runtime.h". You can use `find . -type f -exec sed -i 's:#include "hip_runtime.h":#include "hip/hip_runtime.h":g' {} +` to replace all such references
|
||||
|
||||
|
||||
===================================================================================================
|
||||
Release:0.92.00
|
||||
Date: 2016.8.14
|
||||
- hipLaunchKernel supports one-dimensional grid and/or block dims, without explicit cast to dim3 type (actually in 0.90.00)
|
||||
- fp16 software support
|
||||
- Support for Hawaii dGPUs using environment variable ROCM_TARGET=hawaii
|
||||
|
||||
@@ -116,9 +116,16 @@ if ($HIP_PLATFORM eq "hcc") {
|
||||
} else {
|
||||
$HIPLDFLAGS .= " -Wl,--defsym=_binary_kernel_spir_end=1 -Wl,--defsym=_binary_kernel_spir_start=1 -Wl,--defsym=_binary_kernel_cl_start=1 -Wl,--defsym=_binary_kernel_cl_end=1";
|
||||
}
|
||||
if ($HOST_OSNAME eq "fedora") {
|
||||
$HIPCXXFLAGS .= " -I/usr/local/include/c++/v1";
|
||||
}
|
||||
|
||||
# Satisfy HCC dependencies
|
||||
$HIPLDFLAGS .= " -lc++abi -lsupc++";
|
||||
if ($HOST_OSNAME eq "fedora") {
|
||||
$HIPLDFLAGS .= " -lc++abi";
|
||||
} else {
|
||||
$HIPLDFLAGS .= " -lc++abi -lsupc++";
|
||||
}
|
||||
$HIPLDFLAGS .= " -L$HSA_PATH/lib -L$ROCM_PATH/lib -lhsa-runtime64 -lhc_am -lhsakmt";
|
||||
|
||||
# Handle ROCm target platform
|
||||
|
||||
@@ -654,7 +654,6 @@ inline hipError_t hipProfilerStop()
|
||||
return hipCUDAErrorTohipError(cudaProfilerStop());
|
||||
}
|
||||
|
||||
|
||||
inline static hipError_t hipSetDeviceFlags (unsigned int flags)
|
||||
{
|
||||
return hipCUDAErrorTohipError(cudaSetDeviceFlags(flags));
|
||||
|
||||
Reference in New Issue
Block a user